Documentation
¶
Index ¶
- Constants
- func Arrowheads(connection d2target.Connection, srcAdj, dstAdj *geo.Point) (string, error)
- func Class(shape d2target.Shape) (string, error)
- func Connection(connection d2target.Connection, path, attrs string) (string, error)
- func DefineFillPatterns(buf *bytes.Buffer, diagramHash string)
- func DoubleOval(shape d2target.Shape, diagramHash string) (string, error)
- func DoubleRect(shape d2target.Shape, diagramHash string) (string, error)
- func Oval(shape d2target.Shape, diagramHash string) (string, error)
- func Paths(shape d2target.Shape, diagramHash string, paths []string) (string, error)
- func Rect(shape d2target.Shape, diagramHash string) (string, error)
- func Table(shape d2target.Shape) (string, error)
Constants ¶
const ( BG_COLOR = color.N7 FG_COLOR = color.N1 )
Variables ¶
This section is empty.
Functions ¶
func Arrowheads ¶
func Connection ¶
func Connection(connection d2target.Connection, path, attrs string) (string, error)
func DefineFillPatterns ¶
DefineFillPatterns adds reusable patterns that are overlayed on shapes with fill. This gives it a subtle streaky effect that subtly looks hand-drawn but not distractingly so.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.